<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Circle</name>
    <message>
        <location filename="../Circle.js" line="+71"/>
        <source>Circle Tools</source>
        <translation>画圆工具</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show circle tools</source>
        <translation>显示画圆工具</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Circle</source>
        <translation>圆(&amp;C)</translation>
    </message>
</context>
</TS>
